Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterHubServiceServer(s grpc.ServiceRegistrar, srv HubServiceServer)
- type CreateHubRequest
- func (*CreateHubRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateHubRequest) GetHub() *Hub
- func (x *CreateHubRequest) GetHubId() string
- func (x *CreateHubRequest) GetParent() string
- func (x *CreateHubRequest) GetRequestId() string
- func (*CreateHubRequest) ProtoMessage()
- func (x *CreateHubRequest) ProtoReflect() protoreflect.Message
- func (x *CreateHubRequest) Reset()
- func (x *CreateHubRequest) String() string
- type CreateSpokeRequest
- func (*CreateSpokeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateSpokeRequest) GetParent() string
- func (x *CreateSpokeRequest) GetRequestId() string
- func (x *CreateSpokeRequest) GetSpoke() *Spoke
- func (x *CreateSpokeRequest) GetSpokeId() string
- func (*CreateSpokeRequest) ProtoMessage()
- func (x *CreateSpokeRequest) ProtoReflect() protoreflect.Message
- func (x *CreateSpokeRequest) Reset()
- func (x *CreateSpokeRequest) String() string
- type DeleteHubRequest
- func (*DeleteHubRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteHubRequest) GetName() string
- func (x *DeleteHubRequest) GetRequestId() string
- func (*DeleteHubRequest) ProtoMessage()
- func (x *DeleteHubRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteHubRequest) Reset()
- func (x *DeleteHubRequest) String() string
- type DeleteSpokeRequest
- func (*DeleteSpokeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteSpokeRequest) GetName() string
- func (x *DeleteSpokeRequest) GetRequestId() string
- func (*DeleteSpokeRequest) ProtoMessage()
- func (x *DeleteSpokeRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteSpokeRequest) Reset()
- func (x *DeleteSpokeRequest) String() string
- type GetHubRequest
- type GetSpokeRequest
- type Hub
- func (*Hub) Descriptor() ([]byte, []int)deprecated
- func (x *Hub) GetCreateTime() *timestamppb.Timestamp
- func (x *Hub) GetDescription() string
- func (x *Hub) GetLabels() map[string]string
- func (x *Hub) GetName() string
- func (x *Hub) GetSpokes() []string
- func (x *Hub) GetState() State
- func (x *Hub) GetUniqueId() string
- func (x *Hub) GetUpdateTime() *timestamppb.Timestamp
- func (*Hub) ProtoMessage()
- func (x *Hub) ProtoReflect() protoreflect.Message
- func (x *Hub) Reset()
- func (x *Hub) String() string
- type HubServiceClient
- type HubServiceServer
- type ListHubsRequest
- func (*ListHubsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListHubsRequest) GetFilter() string
- func (x *ListHubsRequest) GetOrderBy() string
- func (x *ListHubsRequest) GetPageSize() int32
- func (x *ListHubsRequest) GetPageToken() string
- func (x *ListHubsRequest) GetParent() string
- func (*ListHubsRequest) ProtoMessage()
- func (x *ListHubsRequest) ProtoReflect() protoreflect.Message
- func (x *ListHubsRequest) Reset()
- func (x *ListHubsRequest) String() string
- type ListHubsResponse
- func (*ListHubsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListHubsResponse) GetHubs() []*Hub
- func (x *ListHubsResponse) GetNextPageToken() string
- func (x *ListHubsResponse) GetUnreachable() []string
- func (*ListHubsResponse) ProtoMessage()
- func (x *ListHubsResponse) ProtoReflect() protoreflect.Message
- func (x *ListHubsResponse) Reset()
- func (x *ListHubsResponse) String() string
- type ListSpokesRequest
- func (*ListSpokesRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListSpokesRequest) GetFilter() string
- func (x *ListSpokesRequest) GetOrderBy() string
- func (x *ListSpokesRequest) GetPageSize() int32
- func (x *ListSpokesRequest) GetPageToken() string
- func (x *ListSpokesRequest) GetParent() string
- func (*ListSpokesRequest) ProtoMessage()
- func (x *ListSpokesRequest) ProtoReflect() protoreflect.Message
- func (x *ListSpokesRequest) Reset()
- func (x *ListSpokesRequest) String() string
- type ListSpokesResponse
- func (*ListSpokesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListSpokesResponse) GetNextPageToken() string
- func (x *ListSpokesResponse) GetSpokes() []*Spoke
- func (x *ListSpokesResponse) GetUnreachable() []string
- func (*ListSpokesResponse) ProtoMessage()
- func (x *ListSpokesResponse) ProtoReflect() protoreflect.Message
- func (x *ListSpokesResponse) Reset()
- func (x *ListSpokesResponse) String() string
- type OperationMetadata
- func (*OperationMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *OperationMetadata) GetApiVersion() string
- func (x *OperationMetadata) GetCreateTime() *timestamppb.Timestamp
- func (x *OperationMetadata) GetEndTime() *timestamppb.Timestamp
- func (x *OperationMetadata) GetRequestedCancellation() bool
- func (x *OperationMetadata) GetStatusMessage() string
- func (x *OperationMetadata) GetTarget() string
- func (x *OperationMetadata) GetVerb() string
- func (*OperationMetadata) ProtoMessage()
- func (x *OperationMetadata) ProtoReflect() protoreflect.Message
- func (x *OperationMetadata) Reset()
- func (x *OperationMetadata) String() string
- type RouterApplianceInstance
- func (*RouterApplianceInstance) Descriptor() ([]byte, []int)deprecated
- func (x *RouterApplianceInstance) GetIpAddress() string
- func (x *RouterApplianceInstance) GetNetworkInterface() stringdeprecated
- func (x *RouterApplianceInstance) GetVirtualMachine() string
- func (*RouterApplianceInstance) ProtoMessage()
- func (x *RouterApplianceInstance) ProtoReflect() protoreflect.Message
- func (x *RouterApplianceInstance) Reset()
- func (x *RouterApplianceInstance) String() string
- type Spoke
- func (*Spoke) Descriptor() ([]byte, []int)deprecated
- func (x *Spoke) GetCreateTime() *timestamppb.Timestamp
- func (x *Spoke) GetDescription() string
- func (x *Spoke) GetHub() string
- func (x *Spoke) GetLabels() map[string]string
- func (x *Spoke) GetLinkedInterconnectAttachments() []string
- func (x *Spoke) GetLinkedRouterApplianceInstances() []*RouterApplianceInstance
- func (x *Spoke) GetLinkedVpnTunnels() []string
- func (x *Spoke) GetName() string
- func (x *Spoke) GetState() State
- func (x *Spoke) GetUniqueId() string
- func (x *Spoke) GetUpdateTime() *timestamppb.Timestamp
- func (*Spoke) ProtoMessage()
- func (x *Spoke) ProtoReflect() protoreflect.Message
- func (x *Spoke) Reset()
- func (x *Spoke) String() string
- type State
- type UnimplementedHubServiceServer
- func (UnimplementedHubServiceServer) CreateHub(context.Context, *CreateHubRequest) (*longrunningpb.Operation, error)
- func (UnimplementedHubServiceServer) CreateSpoke(context.Context, *CreateSpokeRequest) (*longrunningpb.Operation, error)
- func (UnimplementedHubServiceServer) DeleteHub(context.Context, *DeleteHubRequest) (*longrunningpb.Operation, error)
- func (UnimplementedHubServiceServer) DeleteSpoke(context.Context, *DeleteSpokeRequest) (*longrunningpb.Operation, error)
- func (UnimplementedHubServiceServer) GetHub(context.Context, *GetHubRequest) (*Hub, error)
- func (UnimplementedHubServiceServer) GetSpoke(context.Context, *GetSpokeRequest) (*Spoke, error)
- func (UnimplementedHubServiceServer) ListHubs(context.Context, *ListHubsRequest) (*ListHubsResponse, error)
- func (UnimplementedHubServiceServer) ListSpokes(context.Context, *ListSpokesRequest) (*ListSpokesResponse, error)
- func (UnimplementedHubServiceServer) UpdateHub(context.Context, *UpdateHubRequest) (*longrunningpb.Operation, error)
- func (UnimplementedHubServiceServer) UpdateSpoke(context.Context, *UpdateSpokeRequest) (*longrunningpb.Operation, error)
- type UnsafeHubServiceServer
- type UpdateHubRequest
- func (*UpdateHubRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateHubRequest) GetHub() *Hub
- func (x *UpdateHubRequest) GetRequestId() string
- func (x *UpdateHubRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateHubRequest) ProtoMessage()
- func (x *UpdateHubRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateHubRequest) Reset()
- func (x *UpdateHubRequest) String() string
- type UpdateSpokeRequest
- func (*UpdateSpokeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateSpokeRequest) GetRequestId() string
- func (x *UpdateSpokeRequest) GetSpoke() *Spoke
- func (x *UpdateSpokeRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateSpokeRequest) ProtoMessage()
- func (x *UpdateSpokeRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateSpokeRequest) Reset()
- func (x *UpdateSpokeRequest) String() string
Constants ¶
const ( HubService_ListHubs_FullMethodName = "/google.cloud.networkconnectivity.v1alpha1.HubService/ListHubs" HubService_GetHub_FullMethodName = "/google.cloud.networkconnectivity.v1alpha1.HubService/GetHub" HubService_CreateHub_FullMethodName = "/google.cloud.networkconnectivity.v1alpha1.HubService/CreateHub" HubService_UpdateHub_FullMethodName = "/google.cloud.networkconnectivity.v1alpha1.HubService/UpdateHub" HubService_DeleteHub_FullMethodName = "/google.cloud.networkconnectivity.v1alpha1.HubService/DeleteHub" HubService_ListSpokes_FullMethodName = "/google.cloud.networkconnectivity.v1alpha1.HubService/ListSpokes" HubService_GetSpoke_FullMethodName = "/google.cloud.networkconnectivity.v1alpha1.HubService/GetSpoke" HubService_CreateSpoke_FullMethodName = "/google.cloud.networkconnectivity.v1alpha1.HubService/CreateSpoke" HubService_UpdateSpoke_FullMethodName = "/google.cloud.networkconnectivity.v1alpha1.HubService/UpdateSpoke" HubService_DeleteSpoke_FullMethodName = "/google.cloud.networkconnectivity.v1alpha1.HubService/DeleteSpoke" )
Variables ¶
var ( State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 1: "CREATING", 2: "ACTIVE", 3: "DELETING", } State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "CREATING": 1, "ACTIVE": 2, "DELETING": 3, } )
Enum value maps for State.
var File_google_cloud_networkconnectivity_v1alpha1_common_proto protoreflect.FileDescriptor
var File_google_cloud_networkconnectivity_v1alpha1_hub_proto protoreflect.FileDescriptor
var HubService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.cloud.networkconnectivity.v1alpha1.HubService", HandlerType: (*HubServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListHubs", Handler: _HubService_ListHubs_Handler, }, { MethodName: "GetHub", Handler: _HubService_GetHub_Handler, }, { MethodName: "CreateHub", Handler: _HubService_CreateHub_Handler, }, { MethodName: "UpdateHub", Handler: _HubService_UpdateHub_Handler, }, { MethodName: "DeleteHub", Handler: _HubService_DeleteHub_Handler, }, { MethodName: "ListSpokes", Handler: _HubService_ListSpokes_Handler, }, { MethodName: "GetSpoke", Handler: _HubService_GetSpoke_Handler, }, { MethodName: "CreateSpoke", Handler: _HubService_CreateSpoke_Handler, }, { MethodName: "UpdateSpoke", Handler: _HubService_UpdateSpoke_Handler, }, { MethodName: "DeleteSpoke", Handler: _HubService_DeleteSpoke_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "google/cloud/networkconnectivity/v1alpha1/hub.proto", }
HubService_ServiceDesc is the grpc.ServiceDesc for HubService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterHubServiceServer ¶
func RegisterHubServiceServer(s grpc.ServiceRegistrar, srv HubServiceServer)
Types ¶
type CreateHubRequest ¶
type CreateHubRequest struct {
// Required. The parent resource's name of the Hub.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Optional. Unique id for the Hub to create.
HubId string `protobuf:"bytes,2,opt,name=hub_id,json=hubId,proto3" json:"hub_id,omitempty"`
// Required. Initial values for a new Hub.
Hub *Hub `protobuf:"bytes,3,opt,name=hub,proto3" json:"hub,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique request ID
// so that if you must retry your request, the server will know to ignore
// the request if it has already been completed. The server will guarantee
// that for at least 60 minutes since the first request.
//
// For example, consider a situation where you make an initial request and t
// he request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,4,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Request for [HubService.CreateHub][google.cloud.networkconnectivity.v1alpha1.HubService.CreateHub] method.
func (*CreateHubRequest) Descriptor
deprecated
func (*CreateHubRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateHubRequest.ProtoReflect.Descriptor instead.
func (*CreateHubRequest) GetHub ¶
func (x *CreateHubRequest) GetHub() *Hub
func (*CreateHubRequest) GetHubId ¶
func (x *CreateHubRequest) GetHubId() string
func (*CreateHubRequest) GetParent ¶
func (x *CreateHubRequest) GetParent() string
func (*CreateHubRequest) GetRequestId ¶
func (x *CreateHubRequest) GetRequestId() string
func (*CreateHubRequest) ProtoMessage ¶
func (*CreateHubRequest) ProtoMessage()
func (*CreateHubRequest) ProtoReflect ¶
func (x *CreateHubRequest) ProtoReflect() protoreflect.Message
func (*CreateHubRequest) Reset ¶
func (x *CreateHubRequest) Reset()
func (*CreateHubRequest) String ¶
func (x *CreateHubRequest) String() string
type CreateSpokeRequest ¶
type CreateSpokeRequest struct {
// Required. The parent's resource name of the Spoke.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Optional. Unique id for the Spoke to create.
SpokeId string `protobuf:"bytes,2,opt,name=spoke_id,json=spokeId,proto3" json:"spoke_id,omitempty"`
// Required. Initial values for a new Hub.
Spoke *Spoke `protobuf:"bytes,3,opt,name=spoke,proto3" json:"spoke,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique request ID
// so that if you must retry your request, the server will know to ignore
// the request if it has already been completed. The server will guarantee
// that for at least 60 minutes since the first request.
//
// For example, consider a situation where you make an initial request and t
// he request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,4,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
The request for [HubService.CreateSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.CreateSpoke].
func (*CreateSpokeRequest) Descriptor
deprecated
func (*CreateSpokeRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateSpokeRequest.ProtoReflect.Descriptor instead.
func (*CreateSpokeRequest) GetParent ¶
func (x *CreateSpokeRequest) GetParent() string
func (*CreateSpokeRequest) GetRequestId ¶
func (x *CreateSpokeRequest) GetRequestId() string
func (*CreateSpokeRequest) GetSpoke ¶
func (x *CreateSpokeRequest) GetSpoke() *Spoke
func (*CreateSpokeRequest) GetSpokeId ¶
func (x *CreateSpokeRequest) GetSpokeId() string
func (*CreateSpokeRequest) ProtoMessage ¶
func (*CreateSpokeRequest) ProtoMessage()
func (*CreateSpokeRequest) ProtoReflect ¶
func (x *CreateSpokeRequest) ProtoReflect() protoreflect.Message
func (*CreateSpokeRequest) Reset ¶
func (x *CreateSpokeRequest) Reset()
func (*CreateSpokeRequest) String ¶
func (x *CreateSpokeRequest) String() string
type DeleteHubRequest ¶
type DeleteHubRequest struct {
// Required. The name of the Hub to delete.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique request ID
// so that if you must retry your request, the server will know to ignore
// the request if it has already been completed. The server will guarantee
// that for at least 60 minutes after the first request.
//
// For example, consider a situation where you make an initial request and t
// he request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,2,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
The request for [HubService.DeleteHub][google.cloud.networkconnectivity.v1alpha1.HubService.DeleteHub].
func (*DeleteHubRequest) Descriptor
deprecated
func (*DeleteHubRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteHubRequest.ProtoReflect.Descriptor instead.
func (*DeleteHubRequest) GetName ¶
func (x *DeleteHubRequest) GetName() string
func (*DeleteHubRequest) GetRequestId ¶
func (x *DeleteHubRequest) GetRequestId() string
func (*DeleteHubRequest) ProtoMessage ¶
func (*DeleteHubRequest) ProtoMessage()
func (*DeleteHubRequest) ProtoReflect ¶
func (x *DeleteHubRequest) ProtoReflect() protoreflect.Message
func (*DeleteHubRequest) Reset ¶
func (x *DeleteHubRequest) Reset()
func (*DeleteHubRequest) String ¶
func (x *DeleteHubRequest) String() string
type DeleteSpokeRequest ¶
type DeleteSpokeRequest struct {
// Required. The name of the Spoke to delete.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique request ID
// so that if you must retry your request, the server will know to ignore
// the request if it has already been completed. The server will guarantee
// that for at least 60 minutes after the first request.
//
// For example, consider a situation where you make an initial request and t
// he request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,2,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
The request for [HubService.DeleteSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.DeleteSpoke].
func (*DeleteSpokeRequest) Descriptor
deprecated
func (*DeleteSpokeRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteSpokeRequest.ProtoReflect.Descriptor instead.
func (*DeleteSpokeRequest) GetName ¶
func (x *DeleteSpokeRequest) GetName() string
func (*DeleteSpokeRequest) GetRequestId ¶
func (x *DeleteSpokeRequest) GetRequestId() string
func (*DeleteSpokeRequest) ProtoMessage ¶
func (*DeleteSpokeRequest) ProtoMessage()
func (*DeleteSpokeRequest) ProtoReflect ¶
func (x *DeleteSpokeRequest) ProtoReflect() protoreflect.Message
func (*DeleteSpokeRequest) Reset ¶
func (x *DeleteSpokeRequest) Reset()
func (*DeleteSpokeRequest) String ¶
func (x *DeleteSpokeRequest) String() string
type GetHubRequest ¶
type GetHubRequest struct {
// Required. Name of the Hub resource to get.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Request for [HubService.GetHub][google.cloud.networkconnectivity.v1alpha1.HubService.GetHub] method.
func (*GetHubRequest) Descriptor
deprecated
func (*GetHubRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetHubRequest.ProtoReflect.Descriptor instead.
func (*GetHubRequest) GetName ¶
func (x *GetHubRequest) GetName() string
func (*GetHubRequest) ProtoMessage ¶
func (*GetHubRequest) ProtoMessage()
func (*GetHubRequest) ProtoReflect ¶
func (x *GetHubRequest) ProtoReflect() protoreflect.Message
func (*GetHubRequest) Reset ¶
func (x *GetHubRequest) Reset()
func (*GetHubRequest) String ¶
func (x *GetHubRequest) String() string
type GetSpokeRequest ¶
type GetSpokeRequest struct {
// Required. The name of Spoke resource.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
The request for [HubService.GetSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.GetSpoke].
func (*GetSpokeRequest) Descriptor
deprecated
func (*GetSpokeRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetSpokeRequest.ProtoReflect.Descriptor instead.
func (*GetSpokeRequest) GetName ¶
func (x *GetSpokeRequest) GetName() string
func (*GetSpokeRequest) ProtoMessage ¶
func (*GetSpokeRequest) ProtoMessage()
func (*GetSpokeRequest) ProtoReflect ¶
func (x *GetSpokeRequest) ProtoReflect() protoreflect.Message
func (*GetSpokeRequest) Reset ¶
func (x *GetSpokeRequest) Reset()
func (*GetSpokeRequest) String ¶
func (x *GetSpokeRequest) String() string
type Hub ¶
type Hub struct {
// Immutable. The name of a Hub resource.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Time when the Hub was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Time when the Hub was updated.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// User-defined labels.
Labels map[string]string `` /* 139-byte string literal not displayed */
// Short description of the hub resource.
Description string `protobuf:"bytes,5,opt,name=description,proto3" json:"description,omitempty"`
// Output only. A list of the URIs of all attached spokes
Spokes []string `protobuf:"bytes,6,rep,name=spokes,proto3" json:"spokes,omitempty"`
// Output only. Google-generated UUID for this resource. This is unique across all Hub
// resources. If a Hub resource is deleted and another with the same name is
// created, it gets a different unique_id.
UniqueId string `protobuf:"bytes,8,opt,name=unique_id,json=uniqueId,proto3" json:"unique_id,omitempty"`
// Output only. The current lifecycle state of this Hub.
State State `protobuf:"varint,9,opt,name=state,proto3,enum=google.cloud.networkconnectivity.v1alpha1.State" json:"state,omitempty"`
// contains filtered or unexported fields
}
Network Connectivity Center is a hub-and-spoke abstraction for network connectivity management in Google Cloud. It reduces operational complexity through a simple, centralized connectivity management model. Following is the resource message of a hub.
func (*Hub) Descriptor
deprecated
func (*Hub) GetCreateTime ¶
func (x *Hub) GetCreateTime() *timestamppb.Timestamp
func (*Hub) GetDescription ¶
func (*Hub) GetUniqueId ¶
func (*Hub) GetUpdateTime ¶
func (x *Hub) GetUpdateTime() *timestamppb.Timestamp
func (*Hub) ProtoMessage ¶
func (*Hub) ProtoMessage()
func (*Hub) ProtoReflect ¶
func (x *Hub) ProtoReflect() protoreflect.Message
type HubServiceClient ¶
type HubServiceClient interface {
// Lists Hubs in a given project and location.
ListHubs(ctx context.Context, in *ListHubsRequest, opts ...grpc.CallOption) (*ListHubsResponse, error)
// Gets details of a single Hub.
GetHub(ctx context.Context, in *GetHubRequest, opts ...grpc.CallOption) (*Hub, error)
// Creates a new Hub in a given project and location.
CreateHub(ctx context.Context, in *CreateHubRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
// Updates the parameters of a single Hub.
UpdateHub(ctx context.Context, in *UpdateHubRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
// Deletes a single Hub.
DeleteHub(ctx context.Context, in *DeleteHubRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
// Lists Spokes in a given project and location.
ListSpokes(ctx context.Context, in *ListSpokesRequest, opts ...grpc.CallOption) (*ListSpokesResponse, error)
// Gets details of a single Spoke.
GetSpoke(ctx context.Context, in *GetSpokeRequest, opts ...grpc.CallOption) (*Spoke, error)
// Creates a new Spoke in a given project and location.
CreateSpoke(ctx context.Context, in *CreateSpokeRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
// Updates the parameters of a single Spoke.
UpdateSpoke(ctx context.Context, in *UpdateSpokeRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
// Deletes a single Spoke.
DeleteSpoke(ctx context.Context, in *DeleteSpokeRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
}
HubServiceClient is the client API for HubService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewHubServiceClient ¶
func NewHubServiceClient(cc grpc.ClientConnInterface) HubServiceClient
type HubServiceServer ¶
type HubServiceServer interface {
// Lists Hubs in a given project and location.
ListHubs(context.Context, *ListHubsRequest) (*ListHubsResponse, error)
// Gets details of a single Hub.
GetHub(context.Context, *GetHubRequest) (*Hub, error)
// Creates a new Hub in a given project and location.
CreateHub(context.Context, *CreateHubRequest) (*longrunningpb.Operation, error)
// Updates the parameters of a single Hub.
UpdateHub(context.Context, *UpdateHubRequest) (*longrunningpb.Operation, error)
// Deletes a single Hub.
DeleteHub(context.Context, *DeleteHubRequest) (*longrunningpb.Operation, error)
// Lists Spokes in a given project and location.
ListSpokes(context.Context, *ListSpokesRequest) (*ListSpokesResponse, error)
// Gets details of a single Spoke.
GetSpoke(context.Context, *GetSpokeRequest) (*Spoke, error)
// Creates a new Spoke in a given project and location.
CreateSpoke(context.Context, *CreateSpokeRequest) (*longrunningpb.Operation, error)
// Updates the parameters of a single Spoke.
UpdateSpoke(context.Context, *UpdateSpokeRequest) (*longrunningpb.Operation, error)
// Deletes a single Spoke.
DeleteSpoke(context.Context, *DeleteSpokeRequest) (*longrunningpb.Operation, error)
}
HubServiceServer is the server API for HubService service. All implementations should embed UnimplementedHubServiceServer for forward compatibility
type ListHubsRequest ¶
type ListHubsRequest struct {
// Required. The parent resource's name.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// The maximum number of results per page that should be returned.
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// The page token.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// A filter expression that filters the results listed in the response.
Filter string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
// Sort the results by a certain order.
OrderBy string `protobuf:"bytes,5,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
// contains filtered or unexported fields
}
Request for [HubService.ListHubs][google.cloud.networkconnectivity.v1alpha1.HubService.ListHubs] method.
func (*ListHubsRequest) Descriptor
deprecated
func (*ListHubsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListHubsRequest.ProtoReflect.Descriptor instead.
func (*ListHubsRequest) GetFilter ¶
func (x *ListHubsRequest) GetFilter() string
func (*ListHubsRequest) GetOrderBy ¶
func (x *ListHubsRequest) GetOrderBy() string
func (*ListHubsRequest) GetPageSize ¶
func (x *ListHubsRequest) GetPageSize() int32
func (*ListHubsRequest) GetPageToken ¶
func (x *ListHubsRequest) GetPageToken() string
func (*ListHubsRequest) GetParent ¶
func (x *ListHubsRequest) GetParent() string
func (*ListHubsRequest) ProtoMessage ¶
func (*ListHubsRequest) ProtoMessage()
func (*ListHubsRequest) ProtoReflect ¶
func (x *ListHubsRequest) ProtoReflect() protoreflect.Message
func (*ListHubsRequest) Reset ¶
func (x *ListHubsRequest) Reset()
func (*ListHubsRequest) String ¶
func (x *ListHubsRequest) String() string
type ListHubsResponse ¶
type ListHubsResponse struct {
// Hubs to be returned.
Hubs []*Hub `protobuf:"bytes,1,rep,name=hubs,proto3" json:"hubs,omitempty"`
// The next pagination token in the List response. It should be used as
// page_token for the following request. An empty value means no more result.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// Locations that could not be reached.
Unreachable []string `protobuf:"bytes,3,rep,name=unreachable,proto3" json:"unreachable,omitempty"`
// contains filtered or unexported fields
}
Response for [HubService.ListHubs][google.cloud.networkconnectivity.v1alpha1.HubService.ListHubs] method.
func (*ListHubsResponse) Descriptor
deprecated
func (*ListHubsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListHubsResponse.ProtoReflect.Descriptor instead.
func (*ListHubsResponse) GetHubs ¶
func (x *ListHubsResponse) GetHubs() []*Hub
func (*ListHubsResponse) GetNextPageToken ¶
func (x *ListHubsResponse) GetNextPageToken() string
func (*ListHubsResponse) GetUnreachable ¶
func (x *ListHubsResponse) GetUnreachable() []string
func (*ListHubsResponse) ProtoMessage ¶
func (*ListHubsResponse) ProtoMessage()
func (*ListHubsResponse) ProtoReflect ¶
func (x *ListHubsResponse) ProtoReflect() protoreflect.Message
func (*ListHubsResponse) Reset ¶
func (x *ListHubsResponse) Reset()
func (*ListHubsResponse) String ¶
func (x *ListHubsResponse) String() string
type ListSpokesRequest ¶
type ListSpokesRequest struct {
// Required. The parent's resource name.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// The maximum number of results per page that should be returned.
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// The page token.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// A filter expression that filters the results listed in the response.
Filter string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
// Sort the results by a certain order.
OrderBy string `protobuf:"bytes,5,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
// contains filtered or unexported fields
}
The request for [HubService.ListSpokes][google.cloud.networkconnectivity.v1alpha1.HubService.ListSpokes].
func (*ListSpokesRequest) Descriptor
deprecated
func (*ListSpokesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListSpokesRequest.ProtoReflect.Descriptor instead.
func (*ListSpokesRequest) GetFilter ¶
func (x *ListSpokesRequest) GetFilter() string
func (*ListSpokesRequest) GetOrderBy ¶
func (x *ListSpokesRequest) GetOrderBy() string
func (*ListSpokesRequest) GetPageSize ¶
func (x *ListSpokesRequest) GetPageSize() int32
func (*ListSpokesRequest) GetPageToken ¶
func (x *ListSpokesRequest) GetPageToken() string
func (*ListSpokesRequest) GetParent ¶
func (x *ListSpokesRequest) GetParent() string
func (*ListSpokesRequest) ProtoMessage ¶
func (*ListSpokesRequest) ProtoMessage()
func (*ListSpokesRequest) ProtoReflect ¶
func (x *ListSpokesRequest) ProtoReflect() protoreflect.Message
func (*ListSpokesRequest) Reset ¶
func (x *ListSpokesRequest) Reset()
func (*ListSpokesRequest) String ¶
func (x *ListSpokesRequest) String() string
type ListSpokesResponse ¶
type ListSpokesResponse struct {
// Spokes to be returned.
Spokes []*Spoke `protobuf:"bytes,1,rep,name=spokes,proto3" json:"spokes,omitempty"`
// The next pagination token in the List response. It should be used as
// page_token for the following request. An empty value means no more result.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// Locations that could not be reached.
Unreachable []string `protobuf:"bytes,3,rep,name=unreachable,proto3" json:"unreachable,omitempty"`
// contains filtered or unexported fields
}
The response for [HubService.ListSpokes][google.cloud.networkconnectivity.v1alpha1.HubService.ListSpokes].
func (*ListSpokesResponse) Descriptor
deprecated
func (*ListSpokesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListSpokesResponse.ProtoReflect.Descriptor instead.
func (*ListSpokesResponse) GetNextPageToken ¶
func (x *ListSpokesResponse) GetNextPageToken() string
func (*ListSpokesResponse) GetSpokes ¶
func (x *ListSpokesResponse) GetSpokes() []*Spoke
func (*ListSpokesResponse) GetUnreachable ¶
func (x *ListSpokesResponse) GetUnreachable() []string
func (*ListSpokesResponse) ProtoMessage ¶
func (*ListSpokesResponse) ProtoMessage()
func (*ListSpokesResponse) ProtoReflect ¶
func (x *ListSpokesResponse) ProtoReflect() protoreflect.Message
func (*ListSpokesResponse) Reset ¶
func (x *ListSpokesResponse) Reset()
func (*ListSpokesResponse) String ¶
func (x *ListSpokesResponse) String() string
type OperationMetadata ¶
type OperationMetadata struct {
// Output only. The time the operation was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. The time the operation finished running.
EndTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
// Output only. Server-defined resource path for the target of the operation.
Target string `protobuf:"bytes,3,opt,name=target,proto3" json:"target,omitempty"`
// Output only. Name of the verb executed by the operation.
Verb string `protobuf:"bytes,4,opt,name=verb,proto3" json:"verb,omitempty"`
// Output only. Human-readable status of the operation, if any.
StatusMessage string `protobuf:"bytes,5,opt,name=status_message,json=statusMessage,proto3" json:"status_message,omitempty"`
// Output only. Identifies whether the user has requested cancellation
// of the operation. Operations that have successfully been cancelled
// have [Operation.error][] value with a [google.rpc.Status.code][google.rpc.Status.code] of 1,
// corresponding to `Code.CANCELLED`.
RequestedCancellation bool `protobuf:"varint,6,opt,name=requested_cancellation,json=requestedCancellation,proto3" json:"requested_cancellation,omitempty"`
// Output only. API version used to start the operation.
ApiVersion string `protobuf:"bytes,7,opt,name=api_version,json=apiVersion,proto3" json:"api_version,omitempty"`
// contains filtered or unexported fields
}
Represents the metadata of the long-running operation.
func (*OperationMetadata) Descriptor
deprecated
func (*OperationMetadata) Descriptor() ([]byte, []int)
Deprecated: Use OperationMetadata.ProtoReflect.Descriptor instead.
func (*OperationMetadata) GetApiVersion ¶
func (x *OperationMetadata) GetApiVersion() string
func (*OperationMetadata) GetCreateTime ¶
func (x *OperationMetadata) GetCreateTime() *timestamppb.Timestamp
func (*OperationMetadata) GetEndTime ¶
func (x *OperationMetadata) GetEndTime() *timestamppb.Timestamp
func (*OperationMetadata) GetRequestedCancellation ¶
func (x *OperationMetadata) GetRequestedCancellation() bool
func (*OperationMetadata) GetStatusMessage ¶
func (x *OperationMetadata) GetStatusMessage() string
func (*OperationMetadata) GetTarget ¶
func (x *OperationMetadata) GetTarget() string
func (*OperationMetadata) GetVerb ¶
func (x *OperationMetadata) GetVerb() string
func (*OperationMetadata) ProtoMessage ¶
func (*OperationMetadata) ProtoMessage()
func (*OperationMetadata) ProtoReflect ¶
func (x *OperationMetadata) ProtoReflect() protoreflect.Message
func (*OperationMetadata) Reset ¶
func (x *OperationMetadata) Reset()
func (*OperationMetadata) String ¶
func (x *OperationMetadata) String() string
type RouterApplianceInstance ¶
type RouterApplianceInstance struct {
// The URI of the virtual machine resource
VirtualMachine string `protobuf:"bytes,1,opt,name=virtual_machine,json=virtualMachine,proto3" json:"virtual_machine,omitempty"`
// The IP address of the network interface to use for peering.
IpAddress string `protobuf:"bytes,3,opt,name=ip_address,json=ipAddress,proto3" json:"ip_address,omitempty"`
// Deprecated: Marked as deprecated in google/cloud/networkconnectivity/v1alpha1/hub.proto.
NetworkInterface string `protobuf:"bytes,2,opt,name=network_interface,json=networkInterface,proto3" json:"network_interface,omitempty"`
// contains filtered or unexported fields
}
RouterAppliance represents a Router appliance which is specified by a VM URI and a NIC address.
func (*RouterApplianceInstance) Descriptor
deprecated
func (*RouterApplianceInstance) Descriptor() ([]byte, []int)
Deprecated: Use RouterApplianceInstance.ProtoReflect.Descriptor instead.
func (*RouterApplianceInstance) GetIpAddress ¶
func (x *RouterApplianceInstance) GetIpAddress() string
func (*RouterApplianceInstance) GetNetworkInterface
deprecated
func (x *RouterApplianceInstance) GetNetworkInterface() string
Deprecated: Marked as deprecated in google/cloud/networkconnectivity/v1alpha1/hub.proto.
func (*RouterApplianceInstance) GetVirtualMachine ¶
func (x *RouterApplianceInstance) GetVirtualMachine() string
func (*RouterApplianceInstance) ProtoMessage ¶
func (*RouterApplianceInstance) ProtoMessage()
func (*RouterApplianceInstance) ProtoReflect ¶
func (x *RouterApplianceInstance) ProtoReflect() protoreflect.Message
func (*RouterApplianceInstance) Reset ¶
func (x *RouterApplianceInstance) Reset()
func (*RouterApplianceInstance) String ¶
func (x *RouterApplianceInstance) String() string
type Spoke ¶
type Spoke struct {
// Immutable. The name of a Spoke resource.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The time when the Spoke was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// The time when the Spoke was updated.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// User-defined labels.
Labels map[string]string `` /* 139-byte string literal not displayed */
// Short description of the spoke resource
Description string `protobuf:"bytes,5,opt,name=description,proto3" json:"description,omitempty"`
// The resource URL of the hub resource that the spoke is attached to
Hub string `protobuf:"bytes,6,opt,name=hub,proto3" json:"hub,omitempty"`
// The URIs of linked VPN tunnel resources
LinkedVpnTunnels []string `protobuf:"bytes,12,rep,name=linked_vpn_tunnels,json=linkedVpnTunnels,proto3" json:"linked_vpn_tunnels,omitempty"`
// The URIs of linked interconnect attachment resources
LinkedInterconnectAttachments []string `` /* 151-byte string literal not displayed */
// The URIs of linked Router appliance resources
LinkedRouterApplianceInstances []*RouterApplianceInstance `` /* 156-byte string literal not displayed */
// Output only. Google-generated UUID for this resource. This is unique across all Spoke
// resources. If a Spoke resource is deleted and another with the same name is
// created, it gets a different unique_id.
UniqueId string `protobuf:"bytes,11,opt,name=unique_id,json=uniqueId,proto3" json:"unique_id,omitempty"`
// Output only. The current lifecycle state of this Hub.
State State `protobuf:"varint,15,opt,name=state,proto3,enum=google.cloud.networkconnectivity.v1alpha1.State" json:"state,omitempty"`
// contains filtered or unexported fields
}
A Spoke is an abstraction of a network attachment being attached to a Hub. A Spoke can be underlying a VPN tunnel, a VLAN (interconnect) attachment, a Router appliance, etc.
func (*Spoke) Descriptor
deprecated
func (*Spoke) GetCreateTime ¶
func (x *Spoke) GetCreateTime() *timestamppb.Timestamp
func (*Spoke) GetDescription ¶
func (*Spoke) GetLinkedInterconnectAttachments ¶
func (*Spoke) GetLinkedRouterApplianceInstances ¶
func (x *Spoke) GetLinkedRouterApplianceInstances() []*RouterApplianceInstance
func (*Spoke) GetLinkedVpnTunnels ¶
func (*Spoke) GetUniqueId ¶
func (*Spoke) GetUpdateTime ¶
func (x *Spoke) GetUpdateTime() *timestamppb.Timestamp
func (*Spoke) ProtoMessage ¶
func (*Spoke) ProtoMessage()
func (*Spoke) ProtoReflect ¶
func (x *Spoke) ProtoReflect() protoreflect.Message
type State ¶
type State int32
The State enum represents the lifecycle of a Network Connectivity Center resource.
func (State) Descriptor ¶
func (State) Descriptor() protoreflect.EnumDescriptor
func (State) EnumDescriptor
deprecated
func (State) Number ¶
func (x State) Number() protoreflect.EnumNumber
func (State) Type ¶
func (State) Type() protoreflect.EnumType
type UnimplementedHubServiceServer ¶
type UnimplementedHubServiceServer struct {
}
UnimplementedHubServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedHubServiceServer) CreateHub ¶
func (UnimplementedHubServiceServer) CreateHub(context.Context, *CreateHubRequest) (*longrunningpb.Operation, error)
func (UnimplementedHubServiceServer) CreateSpoke ¶
func (UnimplementedHubServiceServer) CreateSpoke(context.Context, *CreateSpokeRequest) (*longrunningpb.Operation, error)
func (UnimplementedHubServiceServer) DeleteHub ¶
func (UnimplementedHubServiceServer) DeleteHub(context.Context, *DeleteHubRequest) (*longrunningpb.Operation, error)
func (UnimplementedHubServiceServer) DeleteSpoke ¶
func (UnimplementedHubServiceServer) DeleteSpoke(context.Context, *DeleteSpokeRequest) (*longrunningpb.Operation, error)
func (UnimplementedHubServiceServer) GetHub ¶
func (UnimplementedHubServiceServer) GetHub(context.Context, *GetHubRequest) (*Hub, error)
func (UnimplementedHubServiceServer) GetSpoke ¶
func (UnimplementedHubServiceServer) GetSpoke(context.Context, *GetSpokeRequest) (*Spoke, error)
func (UnimplementedHubServiceServer) ListHubs ¶
func (UnimplementedHubServiceServer) ListHubs(context.Context, *ListHubsRequest) (*ListHubsResponse, error)
func (UnimplementedHubServiceServer) ListSpokes ¶
func (UnimplementedHubServiceServer) ListSpokes(context.Context, *ListSpokesRequest) (*ListSpokesResponse, error)
func (UnimplementedHubServiceServer) UpdateHub ¶
func (UnimplementedHubServiceServer) UpdateHub(context.Context, *UpdateHubRequest) (*longrunningpb.Operation, error)
func (UnimplementedHubServiceServer) UpdateSpoke ¶
func (UnimplementedHubServiceServer) UpdateSpoke(context.Context, *UpdateSpokeRequest) (*longrunningpb.Operation, error)
type UnsafeHubServiceServer ¶ added in v1.19.1
type UnsafeHubServiceServer interface {
// contains filtered or unexported methods
}
UnsafeHubServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to HubServiceServer will result in compilation errors.
type UpdateHubRequest ¶
type UpdateHubRequest struct {
// Optional. Field mask is used to specify the fields to be overwritten in the
// Hub resource by the update.
// The fields specified in the update_mask are relative to the resource, not
// the full request. A field will be overwritten if it is in the mask. If the
// user does not provide a mask then all fields will be overwritten.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,1,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// Required. The state that the Hub should be in after the update.
Hub *Hub `protobuf:"bytes,2,opt,name=hub,proto3" json:"hub,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique request ID
// so that if you must retry your request, the server will know to ignore
// the request if it has already been completed. The server will guarantee
// that for at least 60 minutes since the first request.
//
// For example, consider a situation where you make an initial request and t
// he request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,3,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Request for [HubService.UpdateHub][google.cloud.networkconnectivity.v1alpha1.HubService.UpdateHub] method.
func (*UpdateHubRequest) Descriptor
deprecated
func (*UpdateHubRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateHubRequest.ProtoReflect.Descriptor instead.
func (*UpdateHubRequest) GetHub ¶
func (x *UpdateHubRequest) GetHub() *Hub
func (*UpdateHubRequest) GetRequestId ¶
func (x *UpdateHubRequest) GetRequestId() string
func (*UpdateHubRequest) GetUpdateMask ¶
func (x *UpdateHubRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateHubRequest) ProtoMessage ¶
func (*UpdateHubRequest) ProtoMessage()
func (*UpdateHubRequest) ProtoReflect ¶
func (x *UpdateHubRequest) ProtoReflect() protoreflect.Message
func (*UpdateHubRequest) Reset ¶
func (x *UpdateHubRequest) Reset()
func (*UpdateHubRequest) String ¶
func (x *UpdateHubRequest) String() string
type UpdateSpokeRequest ¶
type UpdateSpokeRequest struct {
// Optional. Field mask is used to specify the fields to be overwritten in the
// Spoke resource by the update.
// The fields specified in the update_mask are relative to the resource, not
// the full request. A field will be overwritten if it is in the mask. If the
// user does not provide a mask then all fields will be overwritten.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,1,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// Required. The state that the Spoke should be in after the update.
Spoke *Spoke `protobuf:"bytes,2,opt,name=spoke,proto3" json:"spoke,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique request ID
// so that if you must retry your request, the server will know to ignore
// the request if it has already been completed. The server will guarantee
// that for at least 60 minutes since the first request.
//
// For example, consider a situation where you make an initial request and t
// he request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,3,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Request for [HubService.UpdateSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.UpdateSpoke] method.
func (*UpdateSpokeRequest) Descriptor
deprecated
func (*UpdateSpokeRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateSpokeRequest.ProtoReflect.Descriptor instead.
func (*UpdateSpokeRequest) GetRequestId ¶
func (x *UpdateSpokeRequest) GetRequestId() string
func (*UpdateSpokeRequest) GetSpoke ¶
func (x *UpdateSpokeRequest) GetSpoke() *Spoke
func (*UpdateSpokeRequest) GetUpdateMask ¶
func (x *UpdateSpokeRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateSpokeRequest) ProtoMessage ¶
func (*UpdateSpokeRequest) ProtoMessage()
func (*UpdateSpokeRequest) ProtoReflect ¶
func (x *UpdateSpokeRequest) ProtoReflect() protoreflect.Message
func (*UpdateSpokeRequest) Reset ¶
func (x *UpdateSpokeRequest) Reset()
func (*UpdateSpokeRequest) String ¶
func (x *UpdateSpokeRequest) String() string